"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.globalVars = () => `import { Environment } from "./helpers";

export function ChangeValue(key: string, value: any) {
    this[key] = value;
}

export var environment: Environment;`;
exports.bootstrapFile = () => `import { Express } from 'express';
import { ChangeValue } from '../globalVars';
import { Environment } from '../helpers';

export = async function(app: Express) {
    ChangeValue('environment', Environment());
}`;
exports.localEnvironmentContent = () => `{
    "name":  "local"
}`;
exports.currentEnvironmentContent = () => `{
    "name": "local"
}`;
exports.helpersDirectoryIndex = () => `export * from './Environment'`;
exports.environmentHelper = () => `export interface Environment {
    name?: string;
}

export function Environment(): Environment {
    const root = \`\${__dirname}/../..\`;
    const configs = require(\`\${root}/app.config.json\`);
    const environmentsDirectory = configs.environmentsDirectory;
    const currentEnvironmentName = require(\`\${root}/\${environmentsDirectory}/current.env.json\`).name;
    const currentEnvironment = require(\`\${root}/$\{environmentsDirectory}/\${currentEnvironmentName}.env.json\`) as Environment;
    console.log(\`Current environment: \${currentEnvironment.name}\`);
    return currentEnvironment;
}`;
exports.cliConfigTemplate = () => `{
    "controllersDirectory": "source/controllers",
    "routesDirectory": "source/routes",
    "loadControllersScript": "source/config/loadControllers.js",
    "environmentsDirectory": "source/environments"
}`;
exports.apiConfig = () => `import { Hub, HubOptions } from '@codeplace/express-extensions';

const options = {
    bodyParser: {
        json: {
            enabled: true,
            options: { limit: '2mb' }
        }
    },
    cors: { 
        enabled: true
    },
    consign: { 
        includes: ['config', 'routes'],
        options: {
            cwd: process.cwd() + '/source',
            extensions: ['.js', '.json', '.node'],
            verbose: false
        }       
    },
    express: {
        tryCatchMethods: ['get', 'post', 'put', 'delete'],
        errorHandler: (req, res, error) => {
            res.status(500).send(error.message);
        }
    },
    expressValidator: {
        enabled: true
    }
} as HubOptions
    
export default Hub.startServer((port) => console.log(\`Server started on port: \${port}\`), options);`;
exports.packageJson = (type, packageName) => {
    if (type == 'lib') {
        return `{
            "name": "${packageName}",
            "version": "1.0.0",
            "description": "",
            "main": "index.js",
            "scripts": {
                "test": "echo \\"Error: no test specified\\" && exit 1",
                "tsc": "tsc -w"
            },
            "author": "Codeplace",
            "license": "ISC"
        }`;
    }
    else {
        return `{
            "name": "${packageName}",
            "version": "1.0.0",
            "description": "",
            "main": "index.js",
            "scripts": {
                "test": "echo \\"Error: no test specified\\" && exit 1",
                "tsc": "tsc -w",
                "nodemon": "nodemon index",
                "start": "node index"
            },
            "author": "Codeplace",
            "license": "ISC"
        }`;
    }
};
exports.tsconfigJson = () => `{
    "compilerOptions": {
        "target": "es6",
        "module": "commonjs",
        "noImplicitAny": true,
        "removeComments": true,
        "preserveConstEnums": true,
        "sourceMap": true,
        "experimentalDecorators": true
    },
    "exclude": ["node_modules", "**/*.spec.ts"]
}
`;
exports.list = (value) => value.split(',');
//# sourceMappingURL=config.js.map