export const globalVars = () => `import { Environment } from "./helpers";

export function ChangeValue(key: string, value: any) {
    this[key] = value;
}

export var environment: Environment;`

export const bootstrapFile = () => `import { Express } from 'express';
import { ChangeValue } from '../globalVars';
import { Environment } from '../helpers';

export = async function(app: Express) {
    ChangeValue('environment', Environment());
}`

export const localEnvironmentContent = () => `{
    "name":  "local"
}`

export const currentEnvironmentContent = () => `{
    "name": "local"
}`

export const helpersDirectoryIndex = () => `export * from './Environment'`;

export const environmentHelper = () => `export interface Environment {
    name?: string;
}

export function Environment(): Environment {
    const root = \`\${__dirname}/../..\`;
    const configs = require(\`\${root}/app.config.json\`);
    const environmentsDirectory = configs.environmentsDirectory;
    const currentEnvironmentName = require(\`\${root}/\${environmentsDirectory}/current.env.json\`).name;
    const currentEnvironment = require(\`\${root}/$\{environmentsDirectory}/\${currentEnvironmentName}.env.json\`) as Environment;
    console.log(\`Current environment: \${currentEnvironment.name}\`);
    return currentEnvironment;
}`

export const cliConfigTemplate = () => `{
    "controllersDirectory": "source/controllers",
    "routesDirectory": "source/routes",
    "loadControllersScript": "source/config/loadControllers.js",
    "environmentsDirectory": "source/environments"
}`

export const apiConfig = () => `import { Hub, HubOptions } from '@codeplace/express-extensions';

const options = {
    bodyParser: {
        json: {
            enabled: true,
            options: { limit: '2mb' }
        }
    },
    cors: { 
        enabled: true
    },
    consign: { 
        includes: ['config', 'routes'],
        options: {
            cwd: process.cwd() + '/source',
            extensions: ['.js', '.json', '.node'],
            verbose: false
        }       
    },
    express: {
        tryCatchMethods: ['get', 'post', 'put', 'delete'],
        errorHandler: (req, res, error) => {
            res.status(500).send(error.message);
        }
    },
    expressValidator: {
        enabled: true
    }
} as HubOptions
    
export default Hub.startServer((port) => console.log(\`Server started on port: \${port}\`), options);`


export const packageJson = (type: string, packageName: string)  => {
    if(type == 'lib') {
        return `{
            "name": "${packageName}",
            "version": "1.0.0",
            "description": "",
            "main": "index.js",
            "scripts": {
                "test": "echo \\"Error: no test specified\\" && exit 1",
                "tsc": "tsc -w"
            },
            "author": "Codeplace",
            "license": "ISC"
        }`
    } else {
        return `{
            "name": "${packageName}",
            "version": "1.0.0",
            "description": "",
            "main": "index.js",
            "scripts": {
                "test": "echo \\"Error: no test specified\\" && exit 1",
                "tsc": "tsc -w",
                "nodemon": "nodemon index",
                "start": "node index"
            },
            "author": "Codeplace",
            "license": "ISC"
        }`
    }
}

export const tsconfigJson = () => `{
    "compilerOptions": {
        "target": "es6",
        "module": "commonjs",
        "noImplicitAny": true,
        "removeComments": true,
        "preserveConstEnums": true,
        "sourceMap": true,
        "experimentalDecorators": true
    },
    "exclude": ["node_modules", "**/*.spec.ts"]
}
`

export const list = (value: string) => value.split(',');
